==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
export let TomorrowExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TomorrowExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TomorrowExpressionDescriptionMetadata.a == null) {
                TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
            }
            if (a.k(TomorrowExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(TomorrowExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TomorrowExpressionDescriptionMetadata.b(a);
            a.ad("TomorrowExpression", () => new TomorrowExpressionDescription());
            a.ac("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
        }
    }
    TomorrowExpressionDescriptionMetadata.$t = markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/TomorrowExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { TomorrowExpressionDescription } from "./TomorrowExpressionDescription";
/**
 * @hidden
 */
export let TomorrowExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class TomorrowExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (TomorrowExpressionDescriptionMetadata.a == null) {
                TomorrowExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                TomorrowExpressionDescriptionMetadata.c(TomorrowExpressionDescriptionMetadata.a);
            }
            if (a.k(TomorrowExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(TomorrowExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            TomorrowExpressionDescriptionMetadata.b(a);
            a.ae("TomorrowExpression", () => new TomorrowExpressionDescription());
            a.ad("TomorrowExpression", TomorrowExpressionDescriptionMetadata.a);
        }
    }
    TomorrowExpressionDescriptionMetadata.$t = markType(TomorrowExpressionDescriptionMetadata, 'TomorrowExpressionDescriptionMetadata');
    TomorrowExpressionDescriptionMetadata.a = null;
    return TomorrowExpressionDescriptionMetadata;
})();
